------------------------------------------------- 
-- File: bidir8.vhd 
-- Entity: bidir8
-- Architecture: alteramax
-- Author: Osman Celimli
-- Created: 7/30/2011
-- Modified: 7/31/2011
-- VHDL'93 
-- Description: Somewhat-Bidirectional 8-Bit I/O
--   plus a swap control to reverse the order of
--   d7-d0 (for PCE region control).
-------------------------------------------------  
library ieee;
use ieee.std_logic_1164.all;

entity bidir8 is Port(
	inpoutp8	: inout std_logic_vector(7 downto 0);
	tobus8		: in std_logic_vector(7 downto 0);
	frombus8	: out std_logic_vector(7 downto 0);
	oe,swp		: in std_logic
	); 
end entity bidir8;

architecture alteramax of bidir8 is
	signal outbuf8	: std_logic_vector(7 downto 0);
	signal inbuf8	: std_logic_vector(7 downto 0);
begin
	--Route Signals
	frombus8 <= inbuf8;
	outbuf8 <= tobus8;
	--Output
	process(oe, swp, inpoutp8)
	begin
		if(oe = '0') then
			--Output bitswapping (0 = unswapped, 1 = swapped)
			if(swp = '0') then
				inpoutp8 <= outbuf8;
			else
				inpoutp8 <= outbuf8(0) & outbuf8(1) & outbuf8(2) & outbuf8(3) 
					& outbuf8(4) & outbuf8(5) & outbuf8(6) & outbuf8(7);
			end if;
		else
			inpoutp8 <= "ZZZZZZZZ";
		end if;
		--No Input bitswapping
		inbuf8 <= inpoutp8;
	end process;
end alteramax;

